@@ -8,9 +8,9 @@ class TunicsLaser:
     adr = None
     static_adr = "GPIB0::10::INSTR"
 
-    def __init__(self, adr=None, DEBUG_LOGGING=True):
+    def __init__(self, adr=None, TOP_LEVEL_LOGGING=True):
         self.adr = adr if adr is not None else self.static_adr  # use given address or static
-        self.DEBUG_LOGGING = DEBUG_LOGGING
+        self.TOP_LEVEL_LOGGING = TOP_LEVEL_LOGGING
         self.__setup_visa_rm()
         self.__take_instr_from_rm()
         self.__set_instrument()
@@ -44,13 +44,14 @@ class TunicsLaser:
 
     def set_wavelength(self,
                        wl: float,
-                       internal_logging=False) -> None:
+                       response_logging=False,
+                       specific_logging=False) -> None:
         wl_f = f"{wl:8.3f}".replace(" ", "0")
         cmd = f"L={wl_f}\n"
         response = self.send_command(cmd)
-        if self.DEBUG_LOGGING:
-            print(f"Wavelength set to {wl_f} [nm]")
-        if internal_logging:
+        if self.TOP_LEVEL_LOGGING or specific_logging:
+            print(f"Wavelength set to {wl_f.replace('0', '')} [nm]")
+        if response_logging:
             print(f"response: '{response}'")
 
     def get_wavelength(self) -> str:
@@ -62,13 +63,14 @@ class TunicsLaser:
 
     def set_power(self,
                   power: float,
-                  internal_logging=False) -> None:
+                  response_logging=False,
+                  specific_logging=False) -> None:
         pow_f = f"{power:5.2f}".replace(" ", "0")
         cmd = f"P={pow_f}\n"
         response = self.send_command(cmd)
-        if self.DEBUG_LOGGING:
-            print(f"Power set to {pow_f} [mW] or [dBm]")
-        if internal_logging:
+        if self.TOP_LEVEL_LOGGING or specific_logging:
+            print(f"Power set to {pow_f.replace('0', '')} [mW] or [dBm]")
+        if response_logging:
             print(f"response: '{response}'")
 
     def get_power(self) -> str:
@@ -80,13 +82,14 @@ class TunicsLaser:
 
     def set_current(self,
                     current: float,
-                    internal_logging=False) -> None:
+                    response_logging=False,
+                    specific_logging=False) -> None:
         cur_f = f"{current:4.1f}".replace(" ", "0")
         cmd = f"I={cur_f}\n"
         response = self.send_command(cmd)
-        if self.DEBUG_LOGGING:
-            print(f"Power set to {cur_f} [mA]")
-        if internal_logging:
+        if self.TOP_LEVEL_LOGGING or specific_logging:
+            print(f"Power set to {cur_f.replace('0', '')} [mA]")
+        if response_logging:
             print(f"response: '{response}'")
 
     def get_current(self) -> str:
@@ -98,13 +101,14 @@ class TunicsLaser:
 
     def set_opt_freq(self,
                      freq: float,
-                     internal_logging=False) -> None:
+                     response_logging=False,
+                     specific_logging=False) -> None:
         freq_f = f"{freq:8.1f}".replace(" ", "0")
         cmd = f"I={freq_f}\n"
         response = self.send_command(cmd)
-        if self.DEBUG_LOGGING:
-            print(f"Power set to {freq_f} [GHz]")
-        if internal_logging:
+        if self.TOP_LEVEL_LOGGING or specific_logging:
+            print(f"Power set to {freq_f.replace('0', '')} [GHz]")
+        if response_logging:
             print(f"response: '{response}'")
 
     def get_opt_freq(self) -> str:
@@ -115,30 +119,32 @@ class TunicsLaser:
         return self.send_command("f?\n")
 
     def enable(self,
-               internal_logging=False) -> str:
+               response_logging=False,
+               specific_logging=False) -> str:
         """
         Enable laser.
         :return: -> "0"
         """
         cmd = "ENABLE\n"
         response = self.send_command(cmd)
-        if self.DEBUG_LOGGING:
+        if self.TOP_LEVEL_LOGGING or specific_logging:
             print(f"Laser ENABLED")
-        if internal_logging:
+        if response_logging:
             print(f"response: '{response}'")
         return response
 
     def disable(self,
-                internal_logging=False) -> str:
+                response_logging=False,
+                specific_logging=False) -> str:
         """
         Disable laser.
         :return: -> "0"
         """
         cmd = "DISABLE\n"
         response = self.send_command(cmd)
-        if self.DEBUG_LOGGING:
+        if self.TOP_LEVEL_LOGGING or specific_logging:
             print(f"Laser DISABLED")
-        if internal_logging:
+        if response_logging:
             print(f"response: '{response}'")
         return response
 
